// Build don't link:

template<class E> class D
{
};

template<template<class> class D,class E> class C	// ERROR - ref below
{
	D<int,int> d;				// ERROR - arg not match
};

int main()
{
	C<D,int> c;
}
