/* Copyright (C) 2000 Free Software Foundation, Inc.  */

/* { dg-do preprocess } */
/* { dg-options "-std=c99" } */

/* This file is for testing the preprocessor in -std=c99 mode.
   Neil Booth, 2 Dec 2000.  */

#if 1LL
#endif
